{% extends 'klaus/base.html' %} {% block title %} History of {% if path %}{{ path }} - {% endif %} {{ block.super }} {% endblock %} {% block content %} {% include "klaus/includes/tree.inc.html" %}

## {% if subpaths %} History of {% for name, subpath in subpaths %} {{ name }} {% if not loop.last %} / {% endif %} {% endfor %} {% else %} Commit History {% endif %} @{{ rev }} {% comment %} {# TODO: has no way to work atm #} {% if USE_SMARTHTTP %} `git clone {{ url_for('history', repo=repo.name, _external=True) }}` {% endif %} {% endcomment %}

{% include "klaus/includes/pagination.html" %}

{% for commit in history %}
- {{ commit.short_message }} {{ commit.author_name }} {{ commit.commit_datetime|timesince }}
{% endfor %}

{% include "klaus/includes/pagination.html" %}
{% endblock %}